[![Build Status](https://travis-ci.org/adalekin/pytest-toolbelt.svg?branch=master)](https://travis-ci.org/adalekin/pytest-toolbelt) [![Coverage Status](https://coveralls.io/repos/github/adalekin/pytest-toolbelt/badge.svg?branch=master)](https://coveralls.io/github/adalekin/pytest-toolbelt?branch=master)

PyTest Toolbelt
===============

This is just a collection of utilities for pytest, but don't really belong in pytest proper.

Installation
------------

```
pip install pytest-toolbelt
```

Tests
-----

To run the test suite execute the following command in package root folder:

```
python setup.py test
```
